@@ -7,7 +7,7 @@ from PyQt5 import QtWidgets, QtGui, QtCore
 from .gallery import RibbonGallery
 from .separator import RibbonHorizontalSeparator, RibbonVerticalSeparator
 from .toolbutton import RibbonToolButton, ButtonStyle
-from .utils import package_source_dir
+from .utils import data_file_path
 
 
 class RibbonPanelTitle(QtWidgets.QLabel):
@@ -151,7 +151,7 @@ class RibbonPanel(QtWidgets.QFrame):
         self._titleLayout.addWidget(self._titleLabel, 1)
         self._panelOption = RibbonPanelOptionButton()
         self._panelOption.setAutoRaise(True)
-        self._panelOption.setIcon(QtGui.QIcon(package_source_dir() + "/icons/linking.png"))
+        self._panelOption.setIcon(QtGui.QIcon(data_file_path("icons/linking.png")))
         self._panelOption.setIconSize(QtCore.QSize(16, 16))
         self._panelOption.clicked.connect(self.panelOptionClicked)
         self._titleLayout.addWidget(self._panelOption, 0)
